fnss.traffic.trafficmatrices.TrafficMatrix.add_flow — FNSS 0.3.2 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.3.2 documentation »

# fnss.traffic.trafficmatrices.TrafficMatrix.add_flow

`TrafficMatrix.` `add_flow`(origin, destination, volume)

  Add a flow to the traffic matrix

  Parameters : | origin : any hashable type The origin node destination : any hashable type The destination node volume : float The traffic volume

### Navigation

- index
- modules |
- modules |
- FNSS 0.3.2 documentation »